library(bayesPop)
source('test_functions.R')

test.prediction()
test.expressions()
test.expressions.with.VE()
